-- /dequip will unequip melee weapons, ranged weapons, shields, and class items. 
-- Inspired by Garan's Unequipper.

import "Turbine";
import "Turbine.Gameplay";

DequipCommand = class(Turbine.ShellCommand);

function DequipCommand:Execute(command, argumentString)

	action, target = string.match(string.upper(argumentString), "^(%S+)%s*(.*)$");

	if action == nil then

		DequipCommand:UnequipItem(Turbine.Gameplay.Equipment.SecondaryWeapon);
		DequipCommand:UnequipItem(Turbine.Gameplay.Equipment.PrimaryWeapon);
		DequipCommand:UnequipItem(Turbine.Gameplay.Equipment.RangedWeapon);
		DequipCommand:UnequipItem(Turbine.Gameplay.Equipment.Class);

	elseif action == "DROP" then

		if string.find(target, "S") then
			DequipCommand:UnequipItem(Turbine.Gameplay.Equipment.SecondaryWeapon);
		end

		if string.find(target, "P") then
			DequipCommand:UnequipItem(Turbine.Gameplay.Equipment.PrimaryWeapon);
		end

		if string.find(target, "R") then
			DequipCommand:UnequipItem(Turbine.Gameplay.Equipment.RangedWeapon);
		end

		if string.find(target, "C") then
			DequipCommand:UnequipItem(Turbine.Gameplay.Equipment.Class);
		end

	else
		Turbine.Shell.WriteLine("Unrecognized action: " .. action);
	end

end

function DequipCommand:UnequipItem(slot)

	local player    = Turbine.Gameplay.LocalPlayer:GetInstance();
	local inventory = player:GetBackpack();
	local equipment = player:GetEquipment();
	local item      = equipment:GetItem(slot);

	if item == nil then
		return;
	end

	local i = 0;

	for i = 1, inventory:GetSize() do
		if inventory:GetItem(i) == nil then
			inventory:PerformItemDrop(item, i, false);
			return;
		end
	end

	Turbine.Shell.WriteLine("Not free inventory space to unequip " .. item.GetName());
end

function DequipCommand:GetHelp()
	local helpText = "\nusage: /dequip [drop [p][s][r][c]]\n\nDrops slotted equipment into inventory as long as there is enough free space.\n\n"
		.. "The following slots are affected and can be toggled via their first initials: "
		.. "[p]rimary weapon, [s]econdary weapon or shield, [r]anged weapon, [c]lass item.";
	return(helpText);
end

function DequipCommand:GetShortHelp()
	return "Unequip weapons, shields, and class items."
end

-- Create instance and register.
dequip = DequipCommand();
Turbine.Shell.AddCommand("dequip", dequip);
